from pydantic import BaseModel
from typing import Optional


class UserInfo(BaseModel):
    username: str
    user_id: str


class BaseCollectionCreateInfo(BaseModel):
    collection_name: str


class AuthzCollectionCreateInfo(BaseCollectionCreateInfo):
    location: str
    owner_username: Optional[str] = None


class CollectionInfo(BaseModel):
    collection_name: Optional[str] = None
    collection_id: str


class AuthzCollectionInfo(CollectionInfo):
    location: str
    owner: UserInfo


class DocumentInfo(BaseModel):
    type: str
    source: str
    ingest_date: int
    filename: Optional[str] = None
    media_type: Optional[str] = None
    document_id: str
    page_count: int
    vector_count: int


class DeletedDocumentInfo(BaseModel):
    collection_id: str
    document_id: str
    deleted_element_count: int


class DocumentIngestInfo(BaseModel):
    progress: int
    total: int
    document_id: str
    document_type: str
    label: str


class ModelLoadInfo(BaseModel):
    progress: int
    total: int
    model_name: str


class ModelInfo(BaseModel):
    model_name: str


class PromptInfo(BaseModel):
    collection_id: str
    task: str
    user_input: str
    persona: Optional[str] = None
    enhancers: Optional[list[str]] = None
    file_id: Optional[str] = None


class ServiceStatus(BaseModel):
    running: bool


class PromptConfigInfo(BaseModel):
    prompt: Optional[str] = None


class TaskInfo(PromptConfigInfo):
    greeting: str


class TempFileInfo(BaseModel):
    id: str


class WebFile(BaseModel):
    bytes: bytes
    media_type: str



from .models import (
    UserInfo as UserInfo,
    BaseCollectionCreateInfo as BaseCollectionCreateInfo,
    AuthzCollectionCreateInfo as AuthzCollectionCreateInfo,
    CollectionInfo as CollectionInfo,
    AuthzCollectionInfo as AuthzCollectionInfo,
    DocumentInfo as DocumentInfo,
    DeletedDocumentInfo as DeletedDocumentInfo,
    DocumentIngestInfo as DocumentIngestInfo,
    ModelLoadInfo as ModelLoadInfo,
    ModelInfo as ModelInfo,
    PromptInfo as PromptInfo,
    ServiceStatus as ServiceStatus,
    PromptConfigInfo as PromptConfigInfo,
    TaskInfo as TaskInfo,
    TempFileInfo as TempFileInfo,
    WebFile as WebFile,
)
from .exceptions import (
    ShabtiError as ShabtiError,
    CollectionExistsError as CollectionExistsError,
    InvalidLocationError as InvalidLocationError,
    InvalidUserError as InvalidUserError,
    UnsupportedFileError as UnsupportedFileError,
)



class ShabtiError(Exception):
    def __init__(self, message="", status=400):
        self.message = message
        self.status = status


class CollectionExistsError(ShabtiError):
    def __init__(self, collection_name, message="", location=None):
        super().__init__(message, 409)
        self.collection_name = collection_name
        self.location = location


class InvalidLocationError(ShabtiError):
    def __init__(self, message='location must be "private" or "shared"'):
        super().__init__(message)


class InvalidUserError(ShabtiError):
    def __init__(self, message=""):
        super().__init__(message)


class UnsupportedFileError(Exception):
    def __init__(self, filename, message=""):
        self.message = message
        self.filename = filename
